# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.akamai_net_storage_output import AkamaiNetStorageOutput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_net_storage_output_list_query_params import AkamaiNetStorageOutputListQueryParams


class AkamaiNetstorageApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AkamaiNetstorageApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, akamai_net_storage_output, **kwargs):
        # type: (AkamaiNetStorageOutput, dict) -> AkamaiNetStorageOutput
        """Create Akamai NetStorage Output

        :param akamai_net_storage_output: The Akamai NetStorage output to be created
        :type akamai_net_storage_output: AkamaiNetStorageOutput, required
        :return: Akamai NetStorage output
        :rtype: AkamaiNetStorageOutput
        """

        return self.api_client.post(
            '/encoding/outputs/akamai-netstorage',
            akamai_net_storage_output,
            type=AkamaiNetStorageOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> AkamaiNetStorageOutput
        """Delete Akamai NetStorage Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the output
        :rtype: AkamaiNetStorageOutput
        """

        return self.api_client.delete(
            '/encoding/outputs/akamai-netstorage/{output_id}',
            path_params={'output_id': output_id},
            type=AkamaiNetStorageOutput,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> AkamaiNetStorageOutput
        """Akamai NetStorage Output Details

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Akamai NetStorage output
        :rtype: AkamaiNetStorageOutput
        """

        return self.api_client.get(
            '/encoding/outputs/akamai-netstorage/{output_id}',
            path_params={'output_id': output_id},
            type=AkamaiNetStorageOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AkamaiNetStorageOutputListQueryParams, dict) -> AkamaiNetStorageOutput
        """List Akamai NetStorage Outputs

        :param query_params: Query parameters
        :type query_params: AkamaiNetStorageOutputListQueryParams
        :return: List of Akamai NetStorage outputs
        :rtype: AkamaiNetStorageOutput
        """

        return self.api_client.get(
            '/encoding/outputs/akamai-netstorage',
            query_params=query_params,
            pagination_response=True,
            type=AkamaiNetStorageOutput,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.email_notification_with_stream_conditions import EmailNotificationWithStreamConditions
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.notifications.emails.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.emails.encoding.encodings.email_notification_with_stream_conditions_list_query_params import EmailNotificationWithStreamConditionsListQueryParams


class EncodingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.live_input_stream_changed = LiveInputStreamChangedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.error = ErrorApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, EmailNotificationWithStreamConditionsListQueryParams, dict) -> EmailNotificationWithStreamConditions
        """List Email Notifications (Specific Encoding)

        :param encoding_id: Id of the encoding resource
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: EmailNotificationWithStreamConditionsListQueryParams
        :return: List of Email Notifications
        :rtype: EmailNotificationWithStreamConditions
        """

        return self.api_client.get(
            '/notifications/emails/encoding/encodings/{encoding_id}',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=EmailNotificationWithStreamConditions,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.streams_config_response import StreamsConfigResponse
from bitmovin_api_sdk.models.streams_live_life_cycle import StreamsLiveLifeCycle
import pprint
import six


class StreamsLiveResponse(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 stream_key=None,
                 title=None,
                 description=None,
                 created_at=None,
                 life_cycle=None,
                 config=None,
                 poster_url=None):
        # type: (string_types, string_types, string_types, string_types, datetime, StreamsLiveLifeCycle, StreamsConfigResponse, string_types) -> None

        self._id = None
        self._stream_key = None
        self._title = None
        self._description = None
        self._created_at = None
        self._life_cycle = None
        self._config = None
        self._poster_url = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if stream_key is not None:
            self.stream_key = stream_key
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if created_at is not None:
            self.created_at = created_at
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if config is not None:
            self.config = config
        if poster_url is not None:
            self.poster_url = poster_url

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'stream_key': 'string_types',
            'title': 'string_types',
            'description': 'string_types',
            'created_at': 'datetime',
            'life_cycle': 'StreamsLiveLifeCycle',
            'config': 'StreamsConfigResponse',
            'poster_url': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'stream_key': 'streamKey',
            'title': 'title',
            'description': 'description',
            'created_at': 'createdAt',
            'life_cycle': 'lifeCycle',
            'config': 'config',
            'poster_url': 'posterUrl'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this StreamsLiveResponse.

        The identifier of the stream

        :return: The id of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this StreamsLiveResponse.

        The identifier of the stream

        :param id_: The id of this StreamsLiveResponse.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this StreamsLiveResponse.

        The streamKey of the stream

        :return: The stream_key of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this StreamsLiveResponse.

        The streamKey of the stream

        :param stream_key: The stream_key of this StreamsLiveResponse.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def title(self):
        # type: () -> string_types
        """Gets the title of this StreamsLiveResponse.

        The title of the stream

        :return: The title of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (string_types) -> None
        """Sets the title of this StreamsLiveResponse.

        The title of the stream

        :param title: The title of this StreamsLiveResponse.
        :type: string_types
        """

        if title is not None:
            if not isinstance(title, string_types):
                raise TypeError("Invalid type for `title`, type has to be `string_types`")

        self._title = title

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this StreamsLiveResponse.

        The description of the stream

        :return: The description of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this StreamsLiveResponse.

        The description of the stream

        :param description: The description of this StreamsLiveResponse.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this StreamsLiveResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this StreamsLiveResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this StreamsLiveResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this StreamsLiveResponse.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def life_cycle(self):
        # type: () -> StreamsLiveLifeCycle
        """Gets the life_cycle of this StreamsLiveResponse.

        The life cycle of the stream

        :return: The life_cycle of this StreamsLiveResponse.
        :rtype: StreamsLiveLifeCycle
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        # type: (StreamsLiveLifeCycle) -> None
        """Sets the life_cycle of this StreamsLiveResponse.

        The life cycle of the stream

        :param life_cycle: The life_cycle of this StreamsLiveResponse.
        :type: StreamsLiveLifeCycle
        """

        if life_cycle is not None:
            if not isinstance(life_cycle, StreamsLiveLifeCycle):
                raise TypeError("Invalid type for `life_cycle`, type has to be `StreamsLiveLifeCycle`")

        self._life_cycle = life_cycle

    @property
    def config(self):
        # type: () -> StreamsConfigResponse
        """Gets the config of this StreamsLiveResponse.


        :return: The config of this StreamsLiveResponse.
        :rtype: StreamsConfigResponse
        """
        return self._config

    @config.setter
    def config(self, config):
        # type: (StreamsConfigResponse) -> None
        """Sets the config of this StreamsLiveResponse.


        :param config: The config of this StreamsLiveResponse.
        :type: StreamsConfigResponse
        """

        if config is not None:
            if not isinstance(config, StreamsConfigResponse):
                raise TypeError("Invalid type for `config`, type has to be `StreamsConfigResponse`")

        self._config = config

    @property
    def poster_url(self):
        # type: () -> string_types
        """Gets the poster_url of this StreamsLiveResponse.

        Poster URL

        :return: The poster_url of this StreamsLiveResponse.
        :rtype: string_types
        """
        return self._poster_url

    @poster_url.setter
    def poster_url(self, poster_url):
        # type: (string_types) -> None
        """Sets the poster_url of this StreamsLiveResponse.

        Poster URL

        :param poster_url: The poster_url of this StreamsLiveResponse.
        :type: string_types
        """

        if poster_url is not None:
            if not isinstance(poster_url, string_types):
                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")

        self._poster_url = poster_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsLiveResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.custom_player_build_details import CustomPlayerBuildDetails
from bitmovin_api_sdk.models.custom_player_build_status import CustomPlayerBuildStatus
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.player.custom_builds.web.domains.domains_api import DomainsApi
from bitmovin_api_sdk.player.custom_builds.web.status.status_api import StatusApi
from bitmovin_api_sdk.player.custom_builds.web.download.download_api import DownloadApi


class WebApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(WebApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.domains = DomainsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.status = StatusApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.download = DownloadApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, custom_player_build_details, **kwargs):
        # type: (CustomPlayerBuildDetails, dict) -> CustomPlayerBuildDetails
        """Add Custom Web Player Build

        :param custom_player_build_details: The Custom Web Player Build to be added
        :type custom_player_build_details: CustomPlayerBuildDetails, required
        :return: Custom player build details
        :rtype: CustomPlayerBuildDetails
        """

        return self.api_client.post(
            '/player/custom-builds/web',
            custom_player_build_details,
            type=CustomPlayerBuildDetails,
            **kwargs
        )

    def get(self, custom_build_id, **kwargs):
        # type: (string_types, dict) -> CustomPlayerBuildStatus
        """Custom Web Player Build Details

        :param custom_build_id: Id of the custom player build
        :type custom_build_id: string_types, required
        :return: Custom player build details
        :rtype: CustomPlayerBuildStatus
        """

        return self.api_client.get(
            '/player/custom-builds/web/{custom_build_id}',
            path_params={'custom_build_id': custom_build_id},
            type=CustomPlayerBuildStatus,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> CustomPlayerBuildDetails
        """List Custom Web Player Builds

        :return: List of player build details
        :rtype: CustomPlayerBuildDetails
        """

        return self.api_client.get(
            '/player/custom-builds/web',
            pagination_response=True,
            type=CustomPlayerBuildDetails,
            **kwargs
        )

    def start(self, custom_build_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Start Custom Web Player Build

        :param custom_build_id: Id of the custom player build
        :type custom_build_id: string_types, required
        :return: Id of custom player build
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/player/custom-builds/web/{custom_build_id}/start',
            path_params={'custom_build_id': custom_build_id},
            type=BitmovinResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.progressive_webm_api import ProgressiveWebmApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_webm.progressive_webm_muxing_list_query_params import ProgressiveWebmMuxingListQueryParams



from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.drm.aes.aes_api import AesApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.drm.aes.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.drm.aes.aes_encryption_drm_list_query_params import AesEncryptionDrmListQueryParams



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint


class Input(BitmovinResource):

    discriminator_value_class_map = {
        'AKAMAI_NETSTORAGE': 'AkamaiNetStorageInput',
        'ASPERA': 'AsperaInput',
        'AZURE': 'AzureInput',
        'REDUNDANT_RTMP': 'RedundantRtmpInput',
        'FTP': 'FtpInput',
        'GENERIC_S3': 'GenericS3Input',
        'GCS': 'GcsInput',
        'HTTP': 'HttpInput',
        'HTTPS': 'HttpsInput',
        'LOCAL': 'LocalInput',
        'RTMP': 'RtmpInput',
        'S3': 'S3Input',
        'S3_ROLE_BASED': 'S3RoleBasedInput',
        'SFTP': 'SftpInput',
        'ZIXI': 'ZixiInput',
        'SRT': 'SrtInput',
        'GCS_SERVICE_ACCOUNT': 'GcsServiceAccountInput',
        'DIRECT_FILE_UPLOAD': 'DirectFileUploadInput'
    }

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Input, self), "to_dict"):
            result = super(Input, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Input):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi
from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.dvb_subtitle_configuration_list_query_params import DvbSubtitleConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.abstract_condition import AbstractCondition
import pprint
import six


class EmailNotificationWithStreamConditionsRequest(object):
    @poscheck_model
    def __init__(self,
                 resolve=None,
                 emails=None,
                 muted=None,
                 conditions=None):
        # type: (bool, list[string_types], bool, AbstractCondition) -> None

        self._resolve = None
        self._emails = list()
        self._muted = None
        self._conditions = None
        self.discriminator = None

        if resolve is not None:
            self.resolve = resolve
        if emails is not None:
            self.emails = emails
        if muted is not None:
            self.muted = muted
        if conditions is not None:
            self.conditions = conditions

    @property
    def openapi_types(self):
        types = {
            'resolve': 'bool',
            'emails': 'list[string_types]',
            'muted': 'bool',
            'conditions': 'AbstractCondition'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'resolve': 'resolve',
            'emails': 'emails',
            'muted': 'muted',
            'conditions': 'conditions'
        }
        return attributes

    @property
    def resolve(self):
        # type: () -> bool
        """Gets the resolve of this EmailNotificationWithStreamConditionsRequest.

        Notify when condition resolves after it was met

        :return: The resolve of this EmailNotificationWithStreamConditionsRequest.
        :rtype: bool
        """
        return self._resolve

    @resolve.setter
    def resolve(self, resolve):
        # type: (bool) -> None
        """Sets the resolve of this EmailNotificationWithStreamConditionsRequest.

        Notify when condition resolves after it was met

        :param resolve: The resolve of this EmailNotificationWithStreamConditionsRequest.
        :type: bool
        """

        if resolve is not None:
            if not isinstance(resolve, bool):
                raise TypeError("Invalid type for `resolve`, type has to be `bool`")

        self._resolve = resolve

    @property
    def emails(self):
        # type: () -> list[string_types]
        """Gets the emails of this EmailNotificationWithStreamConditionsRequest.


        :return: The emails of this EmailNotificationWithStreamConditionsRequest.
        :rtype: list[string_types]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        # type: (list) -> None
        """Sets the emails of this EmailNotificationWithStreamConditionsRequest.


        :param emails: The emails of this EmailNotificationWithStreamConditionsRequest.
        :type: list[string_types]
        """

        if emails is not None:
            if not isinstance(emails, list):
                raise TypeError("Invalid type for `emails`, type has to be `list[string_types]`")

        self._emails = emails

    @property
    def muted(self):
        # type: () -> bool
        """Gets the muted of this EmailNotificationWithStreamConditionsRequest.


        :return: The muted of this EmailNotificationWithStreamConditionsRequest.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        # type: (bool) -> None
        """Sets the muted of this EmailNotificationWithStreamConditionsRequest.


        :param muted: The muted of this EmailNotificationWithStreamConditionsRequest.
        :type: bool
        """

        if muted is not None:
            if not isinstance(muted, bool):
                raise TypeError("Invalid type for `muted`, type has to be `bool`")

        self._muted = muted

    @property
    def conditions(self):
        # type: () -> AbstractCondition
        """Gets the conditions of this EmailNotificationWithStreamConditionsRequest.


        :return: The conditions of this EmailNotificationWithStreamConditionsRequest.
        :rtype: AbstractCondition
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        # type: (AbstractCondition) -> None
        """Sets the conditions of this EmailNotificationWithStreamConditionsRequest.


        :param conditions: The conditions of this EmailNotificationWithStreamConditionsRequest.
        :type: AbstractCondition
        """

        if conditions is not None:
            if not isinstance(conditions, AbstractCondition):
                raise TypeError("Invalid type for `conditions`, type has to be `AbstractCondition`")

        self._conditions = conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailNotificationWithStreamConditionsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.position_unit import PositionUnit
import pprint
import six


class WatermarkFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 image=None,
                 left=None,
                 right=None,
                 top=None,
                 bottom=None,
                 unit=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, int, int, int, int, PositionUnit) -> None
        super(WatermarkFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._image = None
        self._left = None
        self._right = None
        self._top = None
        self._bottom = None
        self._unit = None
        self.discriminator = None

        if image is not None:
            self.image = image
        if left is not None:
            self.left = left
        if right is not None:
            self.right = right
        if top is not None:
            self.top = top
        if bottom is not None:
            self.bottom = bottom
        if unit is not None:
            self.unit = unit

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(WatermarkFilter, self), 'openapi_types'):
            types = getattr(super(WatermarkFilter, self), 'openapi_types')

        types.update({
            'image': 'string_types',
            'left': 'int',
            'right': 'int',
            'top': 'int',
            'bottom': 'int',
            'unit': 'PositionUnit'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(WatermarkFilter, self), 'attribute_map'):
            attributes = getattr(super(WatermarkFilter, self), 'attribute_map')

        attributes.update({
            'image': 'image',
            'left': 'left',
            'right': 'right',
            'top': 'top',
            'bottom': 'bottom',
            'unit': 'unit'
        })
        return attributes

    @property
    def image(self):
        # type: () -> string_types
        """Gets the image of this WatermarkFilter.

        URL of the file to be used as watermark image. Supported image formats: PNG, JPEG, BMP, GIF (required)

        :return: The image of this WatermarkFilter.
        :rtype: string_types
        """
        return self._image

    @image.setter
    def image(self, image):
        # type: (string_types) -> None
        """Sets the image of this WatermarkFilter.

        URL of the file to be used as watermark image. Supported image formats: PNG, JPEG, BMP, GIF (required)

        :param image: The image of this WatermarkFilter.
        :type: string_types
        """

        if image is not None:
            if not isinstance(image, string_types):
                raise TypeError("Invalid type for `image`, type has to be `string_types`")

        self._image = image

    @property
    def left(self):
        # type: () -> int
        """Gets the left of this WatermarkFilter.

        Distance from the left edge of the input video to the left edge of the watermark image. May not be set if 'right' is set.

        :return: The left of this WatermarkFilter.
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        # type: (int) -> None
        """Sets the left of this WatermarkFilter.

        Distance from the left edge of the input video to the left edge of the watermark image. May not be set if 'right' is set.

        :param left: The left of this WatermarkFilter.
        :type: int
        """

        if left is not None:
            if not isinstance(left, int):
                raise TypeError("Invalid type for `left`, type has to be `int`")

        self._left = left

    @property
    def right(self):
        # type: () -> int
        """Gets the right of this WatermarkFilter.

        Distance from the right edge of the input video to the right edge of the watermark image . May not be set if 'left' is set.

        :return: The right of this WatermarkFilter.
        :rtype: int
        """
        return self._right

    @right.setter
    def right(self, right):
        # type: (int) -> None
        """Sets the right of this WatermarkFilter.

        Distance from the right edge of the input video to the right edge of the watermark image . May not be set if 'left' is set.

        :param right: The right of this WatermarkFilter.
        :type: int
        """

        if right is not None:
            if not isinstance(right, int):
                raise TypeError("Invalid type for `right`, type has to be `int`")

        self._right = right

    @property
    def top(self):
        # type: () -> int
        """Gets the top of this WatermarkFilter.

        Distance from the top edge of the input video to the top edge of the watermark image. May not be set if 'bottom' is set.

        :return: The top of this WatermarkFilter.
        :rtype: int
        """
        return self._top

    @top.setter
    def top(self, top):
        # type: (int) -> None
        """Sets the top of this WatermarkFilter.

        Distance from the top edge of the input video to the top edge of the watermark image. May not be set if 'bottom' is set.

        :param top: The top of this WatermarkFilter.
        :type: int
        """

        if top is not None:
            if not isinstance(top, int):
                raise TypeError("Invalid type for `top`, type has to be `int`")

        self._top = top

    @property
    def bottom(self):
        # type: () -> int
        """Gets the bottom of this WatermarkFilter.

        Distance from the bottom edge of the input video to the bottom edge of the watermark image. May not be set if 'top' is set.

        :return: The bottom of this WatermarkFilter.
        :rtype: int
        """
        return self._bottom

    @bottom.setter
    def bottom(self, bottom):
        # type: (int) -> None
        """Sets the bottom of this WatermarkFilter.

        Distance from the bottom edge of the input video to the bottom edge of the watermark image. May not be set if 'top' is set.

        :param bottom: The bottom of this WatermarkFilter.
        :type: int
        """

        if bottom is not None:
            if not isinstance(bottom, int):
                raise TypeError("Invalid type for `bottom`, type has to be `int`")

        self._bottom = bottom

    @property
    def unit(self):
        # type: () -> PositionUnit
        """Gets the unit of this WatermarkFilter.

        Specifies if the values of 'left', 'right', 'top' and 'bottom' are interpreted as pixels or as a percentage of the input video's dimensions.

        :return: The unit of this WatermarkFilter.
        :rtype: PositionUnit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        # type: (PositionUnit) -> None
        """Sets the unit of this WatermarkFilter.

        Specifies if the values of 'left', 'right', 'top' and 'bottom' are interpreted as pixels or as a percentage of the input video's dimensions.

        :param unit: The unit of this WatermarkFilter.
        :type: PositionUnit
        """

        if unit is not None:
            if not isinstance(unit, PositionUnit):
                raise TypeError("Invalid type for `unit`, type has to be `PositionUnit`")

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(WatermarkFilter, self), "to_dict"):
            result = super(WatermarkFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WatermarkFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_plus_dynamic_range_compression_mode import DolbyDigitalPlusDynamicRangeCompressionMode
import pprint
import six


class DolbyDigitalPlusDynamicRangeCompression(object):
    @poscheck_model
    def __init__(self,
                 line_mode=None,
                 rf_mode=None):
        # type: (DolbyDigitalPlusDynamicRangeCompressionMode, DolbyDigitalPlusDynamicRangeCompressionMode) -> None

        self._line_mode = None
        self._rf_mode = None
        self.discriminator = None

        if line_mode is not None:
            self.line_mode = line_mode
        if rf_mode is not None:
            self.rf_mode = rf_mode

    @property
    def openapi_types(self):
        types = {
            'line_mode': 'DolbyDigitalPlusDynamicRangeCompressionMode',
            'rf_mode': 'DolbyDigitalPlusDynamicRangeCompressionMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'line_mode': 'lineMode',
            'rf_mode': 'rfMode'
        }
        return attributes

    @property
    def line_mode(self):
        # type: () -> DolbyDigitalPlusDynamicRangeCompressionMode
        """Gets the line_mode of this DolbyDigitalPlusDynamicRangeCompression.

        Line mode is intended for use in products providing line‐level or speaker‐level outputs, and is applicable to the widest range of products.  Products such as set‐top boxes, DVD players, DTVs, A/V surround decoders, and outboard Dolby Digital decoders typically use this mode. 

        :return: The line_mode of this DolbyDigitalPlusDynamicRangeCompression.
        :rtype: DolbyDigitalPlusDynamicRangeCompressionMode
        """
        return self._line_mode

    @line_mode.setter
    def line_mode(self, line_mode):
        # type: (DolbyDigitalPlusDynamicRangeCompressionMode) -> None
        """Sets the line_mode of this DolbyDigitalPlusDynamicRangeCompression.

        Line mode is intended for use in products providing line‐level or speaker‐level outputs, and is applicable to the widest range of products.  Products such as set‐top boxes, DVD players, DTVs, A/V surround decoders, and outboard Dolby Digital decoders typically use this mode. 

        :param line_mode: The line_mode of this DolbyDigitalPlusDynamicRangeCompression.
        :type: DolbyDigitalPlusDynamicRangeCompressionMode
        """

        if line_mode is not None:
            if not isinstance(line_mode, DolbyDigitalPlusDynamicRangeCompressionMode):
                raise TypeError("Invalid type for `line_mode`, type has to be `DolbyDigitalPlusDynamicRangeCompressionMode`")

        self._line_mode = line_mode

    @property
    def rf_mode(self):
        # type: () -> DolbyDigitalPlusDynamicRangeCompressionMode
        """Gets the rf_mode of this DolbyDigitalPlusDynamicRangeCompression.

        RF mode is intended for products such as a low‐cost television receiver.

        :return: The rf_mode of this DolbyDigitalPlusDynamicRangeCompression.
        :rtype: DolbyDigitalPlusDynamicRangeCompressionMode
        """
        return self._rf_mode

    @rf_mode.setter
    def rf_mode(self, rf_mode):
        # type: (DolbyDigitalPlusDynamicRangeCompressionMode) -> None
        """Sets the rf_mode of this DolbyDigitalPlusDynamicRangeCompression.

        RF mode is intended for products such as a low‐cost television receiver.

        :param rf_mode: The rf_mode of this DolbyDigitalPlusDynamicRangeCompression.
        :type: DolbyDigitalPlusDynamicRangeCompressionMode
        """

        if rf_mode is not None:
            if not isinstance(rf_mode, DolbyDigitalPlusDynamicRangeCompressionMode):
                raise TypeError("Invalid type for `rf_mode`, type has to be `DolbyDigitalPlusDynamicRangeCompressionMode`")

        self._rf_mode = rf_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalPlusDynamicRangeCompression):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_level_setup import AutoLevelSetup
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.preset_configuration import PresetConfiguration
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
from bitmovin_api_sdk.models.vp9_aq_mode import Vp9AqMode
from bitmovin_api_sdk.models.vp9_arnr_type import Vp9ArnrType
from bitmovin_api_sdk.models.vp9_dynamic_range_format import Vp9DynamicRangeFormat
from bitmovin_api_sdk.models.vp9_quality import Vp9Quality
import pprint
import six


class Vp9VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 preset_configuration=None,
                 dynamic_range_format=None,
                 crf=None,
                 lag_in_frames=None,
                 error_resiliency_enabled=None,
                 tile_columns=None,
                 tile_rows=None,
                 frame_parallel=None,
                 max_intra_rate=None,
                 qp_min=None,
                 qp_max=None,
                 rate_undershoot_pct=None,
                 rate_overshoot_pct=None,
                 client_buffer_size=None,
                 client_initial_buffer_size=None,
                 bias_pct=None,
                 noise_sensitivity=None,
                 cpu_used=None,
                 automatic_alt_ref_frames_enabled=None,
                 target_level=None,
                 row_multi_threading_enabled=None,
                 sharpness=None,
                 min_gop=None,
                 max_gop=None,
                 min_keyframe_interval=None,
                 max_keyframe_interval=None,
                 quality=None,
                 lossless=None,
                 static_thresh=None,
                 aq_mode=None,
                 arnr_max_frames=None,
                 arnr_strength=None,
                 arnr_type=None,
                 auto_level_setup=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, PresetConfiguration, Vp9DynamicRangeFormat, int, int, bool, int, int, bool, int, int, int, int, int, int, int, int, bool, int, bool, int, bool, int, int, int, float, float, Vp9Quality, bool, int, Vp9AqMode, int, int, Vp9ArnrType, AutoLevelSetup) -> None
        super(Vp9VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._preset_configuration = None
        self._dynamic_range_format = None
        self._crf = None
        self._lag_in_frames = None
        self._error_resiliency_enabled = None
        self._tile_columns = None
        self._tile_rows = None
        self._frame_parallel = None
        self._max_intra_rate = None
        self._qp_min = None
        self._qp_max = None
        self._rate_undershoot_pct = None
        self._rate_overshoot_pct = None
        self._client_buffer_size = None
        self._client_initial_buffer_size = None
        self._bias_pct = None
        self._noise_sensitivity = None
        self._cpu_used = None
        self._automatic_alt_ref_frames_enabled = None
        self._target_level = None
        self._row_multi_threading_enabled = None
        self._sharpness = None
        self._min_gop = None
        self._max_gop = None
        self._min_keyframe_interval = None
        self._max_keyframe_interval = None
        self._quality = None
        self._lossless = None
        self._static_thresh = None
        self._aq_mode = None
        self._arnr_max_frames = None
        self._arnr_strength = None
        self._arnr_type = None
        self._auto_level_setup = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if dynamic_range_format is not None:
            self.dynamic_range_format = dynamic_range_format
        if crf is not None:
            self.crf = crf
        if lag_in_frames is not None:
            self.lag_in_frames = lag_in_frames
        if error_resiliency_enabled is not None:
            self.error_resiliency_enabled = error_resiliency_enabled
        if tile_columns is not None:
            self.tile_columns = tile_columns
        if tile_rows is not None:
            self.tile_rows = tile_rows
        if frame_parallel is not None:
            self.frame_parallel = frame_parallel
        if max_intra_rate is not None:
            self.max_intra_rate = max_intra_rate
        if qp_min is not None:
            self.qp_min = qp_min
        if qp_max is not None:
            self.qp_max = qp_max
        if rate_undershoot_pct is not None:
            self.rate_undershoot_pct = rate_undershoot_pct
        if rate_overshoot_pct is not None:
            self.rate_overshoot_pct = rate_overshoot_pct
        if client_buffer_size is not None:
            self.client_buffer_size = client_buffer_size
        if client_initial_buffer_size is not None:
            self.client_initial_buffer_size = client_initial_buffer_size
        if bias_pct is not None:
            self.bias_pct = bias_pct
        if noise_sensitivity is not None:
            self.noise_sensitivity = noise_sensitivity
        if cpu_used is not None:
            self.cpu_used = cpu_used
        if automatic_alt_ref_frames_enabled is not None:
            self.automatic_alt_ref_frames_enabled = automatic_alt_ref_frames_enabled
        if target_level is not None:
            self.target_level = target_level
        if row_multi_threading_enabled is not None:
            self.row_multi_threading_enabled = row_multi_threading_enabled
        if sharpness is not None:
            self.sharpness = sharpness
        if min_gop is not None:
            self.min_gop = min_gop
        if max_gop is not None:
            self.max_gop = max_gop
        if min_keyframe_interval is not None:
            self.min_keyframe_interval = min_keyframe_interval
        if max_keyframe_interval is not None:
            self.max_keyframe_interval = max_keyframe_interval
        if quality is not None:
            self.quality = quality
        if lossless is not None:
            self.lossless = lossless
        if static_thresh is not None:
            self.static_thresh = static_thresh
        if aq_mode is not None:
            self.aq_mode = aq_mode
        if arnr_max_frames is not None:
            self.arnr_max_frames = arnr_max_frames
        if arnr_strength is not None:
            self.arnr_strength = arnr_strength
        if arnr_type is not None:
            self.arnr_type = arnr_type
        if auto_level_setup is not None:
            self.auto_level_setup = auto_level_setup

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Vp9VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Vp9VideoConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'PresetConfiguration',
            'dynamic_range_format': 'Vp9DynamicRangeFormat',
            'crf': 'int',
            'lag_in_frames': 'int',
            'error_resiliency_enabled': 'bool',
            'tile_columns': 'int',
            'tile_rows': 'int',
            'frame_parallel': 'bool',
            'max_intra_rate': 'int',
            'qp_min': 'int',
            'qp_max': 'int',
            'rate_undershoot_pct': 'int',
            'rate_overshoot_pct': 'int',
            'client_buffer_size': 'int',
            'client_initial_buffer_size': 'int',
            'bias_pct': 'int',
            'noise_sensitivity': 'bool',
            'cpu_used': 'int',
            'automatic_alt_ref_frames_enabled': 'bool',
            'target_level': 'int',
            'row_multi_threading_enabled': 'bool',
            'sharpness': 'int',
            'min_gop': 'int',
            'max_gop': 'int',
            'min_keyframe_interval': 'float',
            'max_keyframe_interval': 'float',
            'quality': 'Vp9Quality',
            'lossless': 'bool',
            'static_thresh': 'int',
            'aq_mode': 'Vp9AqMode',
            'arnr_max_frames': 'int',
            'arnr_strength': 'int',
            'arnr_type': 'Vp9ArnrType',
            'auto_level_setup': 'AutoLevelSetup'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Vp9VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Vp9VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'dynamic_range_format': 'dynamicRangeFormat',
            'crf': 'crf',
            'lag_in_frames': 'lagInFrames',
            'error_resiliency_enabled': 'errorResiliencyEnabled',
            'tile_columns': 'tileColumns',
            'tile_rows': 'tileRows',
            'frame_parallel': 'frameParallel',
            'max_intra_rate': 'maxIntraRate',
            'qp_min': 'qpMin',
            'qp_max': 'qpMax',
            'rate_undershoot_pct': 'rateUndershootPct',
            'rate_overshoot_pct': 'rateOvershootPct',
            'client_buffer_size': 'clientBufferSize',
            'client_initial_buffer_size': 'clientInitialBufferSize',
            'bias_pct': 'biasPct',
            'noise_sensitivity': 'noiseSensitivity',
            'cpu_used': 'cpuUsed',
            'automatic_alt_ref_frames_enabled': 'automaticAltRefFramesEnabled',
            'target_level': 'targetLevel',
            'row_multi_threading_enabled': 'rowMultiThreadingEnabled',
            'sharpness': 'sharpness',
            'min_gop': 'minGop',
            'max_gop': 'maxGop',
            'min_keyframe_interval': 'minKeyframeInterval',
            'max_keyframe_interval': 'maxKeyframeInterval',
            'quality': 'quality',
            'lossless': 'lossless',
            'static_thresh': 'staticThresh',
            'aq_mode': 'aqMode',
            'arnr_max_frames': 'arnrMaxFrames',
            'arnr_strength': 'arnrStrength',
            'arnr_type': 'arnrType',
            'auto_level_setup': 'autoLevelSetup'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> PresetConfiguration
        """Gets the preset_configuration of this Vp9VideoConfiguration.

        Choose from a set of preset configurations tailored for common use cases. Check out [VP9 Presets](https://bitmovin.com/docs/encoding/tutorials/vp9-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.

        :return: The preset_configuration of this Vp9VideoConfiguration.
        :rtype: PresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (PresetConfiguration) -> None
        """Sets the preset_configuration of this Vp9VideoConfiguration.

        Choose from a set of preset configurations tailored for common use cases. Check out [VP9 Presets](https://bitmovin.com/docs/encoding/tutorials/vp9-presets) to see which values get applied by each preset. Explicitly setting a property to a different value will override the preset's value for that property.

        :param preset_configuration: The preset_configuration of this Vp9VideoConfiguration.
        :type: PresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, PresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `PresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def dynamic_range_format(self):
        # type: () -> Vp9DynamicRangeFormat
        """Gets the dynamic_range_format of this Vp9VideoConfiguration.

        Automatically configures the VP9 Video Codec to be compatible with the given SDR/HLG format. Bitmovin recommends to use the dynamic range format together with a preset configuration to achieve good results. Explicitly configured properties will take precedence over dynamic range format settings, which in turn will take precedence over preset configurations.

        :return: The dynamic_range_format of this Vp9VideoConfiguration.
        :rtype: Vp9DynamicRangeFormat
        """
        return self._dynamic_range_format

    @dynamic_range_format.setter
    def dynamic_range_format(self, dynamic_range_format):
        # type: (Vp9DynamicRangeFormat) -> None
        """Sets the dynamic_range_format of this Vp9VideoConfiguration.

        Automatically configures the VP9 Video Codec to be compatible with the given SDR/HLG format. Bitmovin recommends to use the dynamic range format together with a preset configuration to achieve good results. Explicitly configured properties will take precedence over dynamic range format settings, which in turn will take precedence over preset configurations.

        :param dynamic_range_format: The dynamic_range_format of this Vp9VideoConfiguration.
        :type: Vp9DynamicRangeFormat
        """

        if dynamic_range_format is not None:
            if not isinstance(dynamic_range_format, Vp9DynamicRangeFormat):
                raise TypeError("Invalid type for `dynamic_range_format`, type has to be `Vp9DynamicRangeFormat`")

        self._dynamic_range_format = dynamic_range_format

    @property
    def crf(self):
        # type: () -> int
        """Gets the crf of this Vp9VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :return: The crf of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._crf

    @crf.setter
    def crf(self, crf):
        # type: (int) -> None
        """Sets the crf of this Vp9VideoConfiguration.

        Constant rate factor for quality-based variable bitrate. Either bitrate or crf is required.

        :param crf: The crf of this Vp9VideoConfiguration.
        :type: int
        """

        if crf is not None:
            if crf is not None and crf > 63:
                raise ValueError("Invalid value for `crf`, must be a value less than or equal to `63`")
            if crf is not None and crf < 0:
                raise ValueError("Invalid value for `crf`, must be a value greater than or equal to `0`")
            if not isinstance(crf, int):
                raise TypeError("Invalid type for `crf`, type has to be `int`")

        self._crf = crf

    @property
    def lag_in_frames(self):
        # type: () -> int
        """Gets the lag_in_frames of this Vp9VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :return: The lag_in_frames of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._lag_in_frames

    @lag_in_frames.setter
    def lag_in_frames(self, lag_in_frames):
        # type: (int) -> None
        """Sets the lag_in_frames of this Vp9VideoConfiguration.

        Number of frames to look ahead for alternate reference frame selection.

        :param lag_in_frames: The lag_in_frames of this Vp9VideoConfiguration.
        :type: int
        """

        if lag_in_frames is not None:
            if lag_in_frames is not None and lag_in_frames > 25:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value less than or equal to `25`")
            if lag_in_frames is not None and lag_in_frames < 0:
                raise ValueError("Invalid value for `lag_in_frames`, must be a value greater than or equal to `0`")
            if not isinstance(lag_in_frames, int):
                raise TypeError("Invalid type for `lag_in_frames`, type has to be `int`")

        self._lag_in_frames = lag_in_frames

    @property
    def error_resiliency_enabled(self):
        # type: () -> bool
        """Gets the error_resiliency_enabled of this Vp9VideoConfiguration.

        Enables error resiliency feature

        :return: The error_resiliency_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._error_resiliency_enabled

    @error_resiliency_enabled.setter
    def error_resiliency_enabled(self, error_resiliency_enabled):
        # type: (bool) -> None
        """Sets the error_resiliency_enabled of this Vp9VideoConfiguration.

        Enables error resiliency feature

        :param error_resiliency_enabled: The error_resiliency_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if error_resiliency_enabled is not None:
            if not isinstance(error_resiliency_enabled, bool):
                raise TypeError("Invalid type for `error_resiliency_enabled`, type has to be `bool`")

        self._error_resiliency_enabled = error_resiliency_enabled

    @property
    def tile_columns(self):
        # type: () -> int
        """Gets the tile_columns of this Vp9VideoConfiguration.

        Number of tile columns to use, log2. Depending on the encoding width there are limitations on this value. The minimum values are 2 for width >= 1920 and 1 for width >= 1280. The minimum width of each tile is 256 pixels so the maximum values are 0 for width < 256, 1 for width < 512, 2 for width < 1024, 3 for width < 2048, 4 for width < 4096, 5 for width < 8192. If the value is too high or too low it will be overridden.

        :return: The tile_columns of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._tile_columns

    @tile_columns.setter
    def tile_columns(self, tile_columns):
        # type: (int) -> None
        """Sets the tile_columns of this Vp9VideoConfiguration.

        Number of tile columns to use, log2. Depending on the encoding width there are limitations on this value. The minimum values are 2 for width >= 1920 and 1 for width >= 1280. The minimum width of each tile is 256 pixels so the maximum values are 0 for width < 256, 1 for width < 512, 2 for width < 1024, 3 for width < 2048, 4 for width < 4096, 5 for width < 8192. If the value is too high or too low it will be overridden.

        :param tile_columns: The tile_columns of this Vp9VideoConfiguration.
        :type: int
        """

        if tile_columns is not None:
            if tile_columns is not None and tile_columns > 6:
                raise ValueError("Invalid value for `tile_columns`, must be a value less than or equal to `6`")
            if tile_columns is not None and tile_columns < 0:
                raise ValueError("Invalid value for `tile_columns`, must be a value greater than or equal to `0`")
            if not isinstance(tile_columns, int):
                raise TypeError("Invalid type for `tile_columns`, type has to be `int`")

        self._tile_columns = tile_columns

    @property
    def tile_rows(self):
        # type: () -> int
        """Gets the tile_rows of this Vp9VideoConfiguration.

        Number of tile rows to use, log2.

        :return: The tile_rows of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._tile_rows

    @tile_rows.setter
    def tile_rows(self, tile_rows):
        # type: (int) -> None
        """Sets the tile_rows of this Vp9VideoConfiguration.

        Number of tile rows to use, log2.

        :param tile_rows: The tile_rows of this Vp9VideoConfiguration.
        :type: int
        """

        if tile_rows is not None:
            if tile_rows is not None and tile_rows > 2:
                raise ValueError("Invalid value for `tile_rows`, must be a value less than or equal to `2`")
            if tile_rows is not None and tile_rows < 0:
                raise ValueError("Invalid value for `tile_rows`, must be a value greater than or equal to `0`")
            if not isinstance(tile_rows, int):
                raise TypeError("Invalid type for `tile_rows`, type has to be `int`")

        self._tile_rows = tile_rows

    @property
    def frame_parallel(self):
        # type: () -> bool
        """Gets the frame_parallel of this Vp9VideoConfiguration.

        Enable frame parallel decodability features

        :return: The frame_parallel of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._frame_parallel

    @frame_parallel.setter
    def frame_parallel(self, frame_parallel):
        # type: (bool) -> None
        """Sets the frame_parallel of this Vp9VideoConfiguration.

        Enable frame parallel decodability features

        :param frame_parallel: The frame_parallel of this Vp9VideoConfiguration.
        :type: bool
        """

        if frame_parallel is not None:
            if not isinstance(frame_parallel, bool):
                raise TypeError("Invalid type for `frame_parallel`, type has to be `bool`")

        self._frame_parallel = frame_parallel

    @property
    def max_intra_rate(self):
        # type: () -> int
        """Gets the max_intra_rate of this Vp9VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :return: The max_intra_rate of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._max_intra_rate

    @max_intra_rate.setter
    def max_intra_rate(self, max_intra_rate):
        # type: (int) -> None
        """Sets the max_intra_rate of this Vp9VideoConfiguration.

        Maximum I-frame bitrate (percentage) 0=unlimited

        :param max_intra_rate: The max_intra_rate of this Vp9VideoConfiguration.
        :type: int
        """

        if max_intra_rate is not None:
            if not isinstance(max_intra_rate, int):
                raise TypeError("Invalid type for `max_intra_rate`, type has to be `int`")

        self._max_intra_rate = max_intra_rate

    @property
    def qp_min(self):
        # type: () -> int
        """Gets the qp_min of this Vp9VideoConfiguration.

        Minimum quantization factor.

        :return: The qp_min of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._qp_min

    @qp_min.setter
    def qp_min(self, qp_min):
        # type: (int) -> None
        """Sets the qp_min of this Vp9VideoConfiguration.

        Minimum quantization factor.

        :param qp_min: The qp_min of this Vp9VideoConfiguration.
        :type: int
        """

        if qp_min is not None:
            if qp_min is not None and qp_min > 63:
                raise ValueError("Invalid value for `qp_min`, must be a value less than or equal to `63`")
            if qp_min is not None and qp_min < 0:
                raise ValueError("Invalid value for `qp_min`, must be a value greater than or equal to `0`")
            if not isinstance(qp_min, int):
                raise TypeError("Invalid type for `qp_min`, type has to be `int`")

        self._qp_min = qp_min

    @property
    def qp_max(self):
        # type: () -> int
        """Gets the qp_max of this Vp9VideoConfiguration.

        Maximum quantization factor.

        :return: The qp_max of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._qp_max

    @qp_max.setter
    def qp_max(self, qp_max):
        # type: (int) -> None
        """Sets the qp_max of this Vp9VideoConfiguration.

        Maximum quantization factor.

        :param qp_max: The qp_max of this Vp9VideoConfiguration.
        :type: int
        """

        if qp_max is not None:
            if qp_max is not None and qp_max > 63:
                raise ValueError("Invalid value for `qp_max`, must be a value less than or equal to `63`")
            if qp_max is not None and qp_max < 0:
                raise ValueError("Invalid value for `qp_max`, must be a value greater than or equal to `0`")
            if not isinstance(qp_max, int):
                raise TypeError("Invalid type for `qp_max`, type has to be `int`")

        self._qp_max = qp_max

    @property
    def rate_undershoot_pct(self):
        # type: () -> int
        """Gets the rate_undershoot_pct of this Vp9VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :return: The rate_undershoot_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._rate_undershoot_pct

    @rate_undershoot_pct.setter
    def rate_undershoot_pct(self, rate_undershoot_pct):
        # type: (int) -> None
        """Sets the rate_undershoot_pct of this Vp9VideoConfiguration.

        Datarate undershoot (min) target (percentage).

        :param rate_undershoot_pct: The rate_undershoot_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if rate_undershoot_pct is not None:
            if rate_undershoot_pct is not None and rate_undershoot_pct > 100:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value less than or equal to `100`")
            if rate_undershoot_pct is not None and rate_undershoot_pct < 0:
                raise ValueError("Invalid value for `rate_undershoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_undershoot_pct, int):
                raise TypeError("Invalid type for `rate_undershoot_pct`, type has to be `int`")

        self._rate_undershoot_pct = rate_undershoot_pct

    @property
    def rate_overshoot_pct(self):
        # type: () -> int
        """Gets the rate_overshoot_pct of this Vp9VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :return: The rate_overshoot_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._rate_overshoot_pct

    @rate_overshoot_pct.setter
    def rate_overshoot_pct(self, rate_overshoot_pct):
        # type: (int) -> None
        """Sets the rate_overshoot_pct of this Vp9VideoConfiguration.

        Datarate overshoot (max) target (percentage).

        :param rate_overshoot_pct: The rate_overshoot_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if rate_overshoot_pct is not None:
            if rate_overshoot_pct is not None and rate_overshoot_pct > 100:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value less than or equal to `100`")
            if rate_overshoot_pct is not None and rate_overshoot_pct < 0:
                raise ValueError("Invalid value for `rate_overshoot_pct`, must be a value greater than or equal to `0`")
            if not isinstance(rate_overshoot_pct, int):
                raise TypeError("Invalid type for `rate_overshoot_pct`, type has to be `int`")

        self._rate_overshoot_pct = rate_overshoot_pct

    @property
    def client_buffer_size(self):
        # type: () -> int
        """Gets the client_buffer_size of this Vp9VideoConfiguration.

        Client buffer size (ms)

        :return: The client_buffer_size of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._client_buffer_size

    @client_buffer_size.setter
    def client_buffer_size(self, client_buffer_size):
        # type: (int) -> None
        """Sets the client_buffer_size of this Vp9VideoConfiguration.

        Client buffer size (ms)

        :param client_buffer_size: The client_buffer_size of this Vp9VideoConfiguration.
        :type: int
        """

        if client_buffer_size is not None:
            if client_buffer_size is not None and client_buffer_size < 0:
                raise ValueError("Invalid value for `client_buffer_size`, must be a value greater than or equal to `0`")
            if not isinstance(client_buffer_size, int):
                raise TypeError("Invalid type for `client_buffer_size`, type has to be `int`")

        self._client_buffer_size = client_buffer_size

    @property
    def client_initial_buffer_size(self):
        # type: () -> int
        """Gets the client_initial_buffer_size of this Vp9VideoConfiguration.

        Client initial buffer size (ms)

        :return: The client_initial_buffer_size of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._client_initial_buffer_size

    @client_initial_buffer_size.setter
    def client_initial_buffer_size(self, client_initial_buffer_size):
        # type: (int) -> None
        """Sets the client_initial_buffer_size of this Vp9VideoConfiguration.

        Client initial buffer size (ms)

        :param client_initial_buffer_size: The client_initial_buffer_size of this Vp9VideoConfiguration.
        :type: int
        """

        if client_initial_buffer_size is not None:
            if client_initial_buffer_size is not None and client_initial_buffer_size < 0:
                raise ValueError("Invalid value for `client_initial_buffer_size`, must be a value greater than or equal to `0`")
            if not isinstance(client_initial_buffer_size, int):
                raise TypeError("Invalid type for `client_initial_buffer_size`, type has to be `int`")

        self._client_initial_buffer_size = client_initial_buffer_size

    @property
    def bias_pct(self):
        # type: () -> int
        """Gets the bias_pct of this Vp9VideoConfiguration.

        CBR/VBR bias (0=CBR, 100=VBR)

        :return: The bias_pct of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._bias_pct

    @bias_pct.setter
    def bias_pct(self, bias_pct):
        # type: (int) -> None
        """Sets the bias_pct of this Vp9VideoConfiguration.

        CBR/VBR bias (0=CBR, 100=VBR)

        :param bias_pct: The bias_pct of this Vp9VideoConfiguration.
        :type: int
        """

        if bias_pct is not None:
            if bias_pct is not None and bias_pct > 100:
                raise ValueError("Invalid value for `bias_pct`, must be a value less than or equal to `100`")
            if bias_pct is not None and bias_pct < 0:
                raise ValueError("Invalid value for `bias_pct`, must be a value greater than or equal to `0`")
            if not isinstance(bias_pct, int):
                raise TypeError("Invalid type for `bias_pct`, type has to be `int`")

        self._bias_pct = bias_pct

    @property
    def noise_sensitivity(self):
        # type: () -> bool
        """Gets the noise_sensitivity of this Vp9VideoConfiguration.

        Enable noise sensitivity on Y channel

        :return: The noise_sensitivity of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._noise_sensitivity

    @noise_sensitivity.setter
    def noise_sensitivity(self, noise_sensitivity):
        # type: (bool) -> None
        """Sets the noise_sensitivity of this Vp9VideoConfiguration.

        Enable noise sensitivity on Y channel

        :param noise_sensitivity: The noise_sensitivity of this Vp9VideoConfiguration.
        :type: bool
        """

        if noise_sensitivity is not None:
            if not isinstance(noise_sensitivity, bool):
                raise TypeError("Invalid type for `noise_sensitivity`, type has to be `bool`")

        self._noise_sensitivity = noise_sensitivity

    @property
    def cpu_used(self):
        # type: () -> int
        """Gets the cpu_used of this Vp9VideoConfiguration.

        Controls the tradeoff between compression efficiency and encoding speed. Higher values indicate a faster encoding. The minimum value for width * height >= 1280 * 720 is 2. If the value is too low it will be overridden.

        :return: The cpu_used of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._cpu_used

    @cpu_used.setter
    def cpu_used(self, cpu_used):
        # type: (int) -> None
        """Sets the cpu_used of this Vp9VideoConfiguration.

        Controls the tradeoff between compression efficiency and encoding speed. Higher values indicate a faster encoding. The minimum value for width * height >= 1280 * 720 is 2. If the value is too low it will be overridden.

        :param cpu_used: The cpu_used of this Vp9VideoConfiguration.
        :type: int
        """

        if cpu_used is not None:
            if cpu_used is not None and cpu_used > 8:
                raise ValueError("Invalid value for `cpu_used`, must be a value less than or equal to `8`")
            if cpu_used is not None and cpu_used < 1:
                raise ValueError("Invalid value for `cpu_used`, must be a value greater than or equal to `1`")
            if not isinstance(cpu_used, int):
                raise TypeError("Invalid type for `cpu_used`, type has to be `int`")

        self._cpu_used = cpu_used

    @property
    def automatic_alt_ref_frames_enabled(self):
        # type: () -> bool
        """Gets the automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.

        Enable automatic alternate reference frames (2pass only)

        :return: The automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._automatic_alt_ref_frames_enabled

    @automatic_alt_ref_frames_enabled.setter
    def automatic_alt_ref_frames_enabled(self, automatic_alt_ref_frames_enabled):
        # type: (bool) -> None
        """Sets the automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.

        Enable automatic alternate reference frames (2pass only)

        :param automatic_alt_ref_frames_enabled: The automatic_alt_ref_frames_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if automatic_alt_ref_frames_enabled is not None:
            if not isinstance(automatic_alt_ref_frames_enabled, bool):
                raise TypeError("Invalid type for `automatic_alt_ref_frames_enabled`, type has to be `bool`")

        self._automatic_alt_ref_frames_enabled = automatic_alt_ref_frames_enabled

    @property
    def target_level(self):
        # type: () -> int
        """Gets the target_level of this Vp9VideoConfiguration.

        Target level (255: off, 0: only keep level stats; 10: level 1.0; 11: level 1.1; ... 62: level 6.2)

        :return: The target_level of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._target_level

    @target_level.setter
    def target_level(self, target_level):
        # type: (int) -> None
        """Sets the target_level of this Vp9VideoConfiguration.

        Target level (255: off, 0: only keep level stats; 10: level 1.0; 11: level 1.1; ... 62: level 6.2)

        :param target_level: The target_level of this Vp9VideoConfiguration.
        :type: int
        """

        if target_level is not None:
            if target_level is not None and target_level > 255:
                raise ValueError("Invalid value for `target_level`, must be a value less than or equal to `255`")
            if target_level is not None and target_level < 0:
                raise ValueError("Invalid value for `target_level`, must be a value greater than or equal to `0`")
            if not isinstance(target_level, int):
                raise TypeError("Invalid type for `target_level`, type has to be `int`")

        self._target_level = target_level

    @property
    def row_multi_threading_enabled(self):
        # type: () -> bool
        """Gets the row_multi_threading_enabled of this Vp9VideoConfiguration.

        Enable row based non-deterministic multi-threading

        :return: The row_multi_threading_enabled of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._row_multi_threading_enabled

    @row_multi_threading_enabled.setter
    def row_multi_threading_enabled(self, row_multi_threading_enabled):
        # type: (bool) -> None
        """Sets the row_multi_threading_enabled of this Vp9VideoConfiguration.

        Enable row based non-deterministic multi-threading

        :param row_multi_threading_enabled: The row_multi_threading_enabled of this Vp9VideoConfiguration.
        :type: bool
        """

        if row_multi_threading_enabled is not None:
            if not isinstance(row_multi_threading_enabled, bool):
                raise TypeError("Invalid type for `row_multi_threading_enabled`, type has to be `bool`")

        self._row_multi_threading_enabled = row_multi_threading_enabled

    @property
    def sharpness(self):
        # type: () -> int
        """Gets the sharpness of this Vp9VideoConfiguration.

        Loop filter sharpness.

        :return: The sharpness of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._sharpness

    @sharpness.setter
    def sharpness(self, sharpness):
        # type: (int) -> None
        """Sets the sharpness of this Vp9VideoConfiguration.

        Loop filter sharpness.

        :param sharpness: The sharpness of this Vp9VideoConfiguration.
        :type: int
        """

        if sharpness is not None:
            if sharpness is not None and sharpness > 7:
                raise ValueError("Invalid value for `sharpness`, must be a value less than or equal to `7`")
            if sharpness is not None and sharpness < 0:
                raise ValueError("Invalid value for `sharpness`, must be a value greater than or equal to `0`")
            if not isinstance(sharpness, int):
                raise TypeError("Invalid type for `sharpness`, type has to be `int`")

        self._sharpness = sharpness

    @property
    def min_gop(self):
        # type: () -> int
        """Gets the min_gop of this Vp9VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :return: The min_gop of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._min_gop

    @min_gop.setter
    def min_gop(self, min_gop):
        # type: (int) -> None
        """Sets the min_gop of this Vp9VideoConfiguration.

        Minimum GOP length, the minimum distance between I-frames.

        :param min_gop: The min_gop of this Vp9VideoConfiguration.
        :type: int
        """

        if min_gop is not None:
            if not isinstance(min_gop, int):
                raise TypeError("Invalid type for `min_gop`, type has to be `int`")

        self._min_gop = min_gop

    @property
    def max_gop(self):
        # type: () -> int
        """Gets the max_gop of this Vp9VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :return: The max_gop of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._max_gop

    @max_gop.setter
    def max_gop(self, max_gop):
        # type: (int) -> None
        """Sets the max_gop of this Vp9VideoConfiguration.

        Maximum GOP length, the maximum distance between I-frames

        :param max_gop: The max_gop of this Vp9VideoConfiguration.
        :type: int
        """

        if max_gop is not None:
            if not isinstance(max_gop, int):
                raise TypeError("Invalid type for `max_gop`, type has to be `int`")

        self._max_gop = max_gop

    @property
    def min_keyframe_interval(self):
        # type: () -> float
        """Gets the min_keyframe_interval of this Vp9VideoConfiguration.

        Minimum interval in seconds between key frames

        :return: The min_keyframe_interval of this Vp9VideoConfiguration.
        :rtype: float
        """
        return self._min_keyframe_interval

    @min_keyframe_interval.setter
    def min_keyframe_interval(self, min_keyframe_interval):
        # type: (float) -> None
        """Sets the min_keyframe_interval of this Vp9VideoConfiguration.

        Minimum interval in seconds between key frames

        :param min_keyframe_interval: The min_keyframe_interval of this Vp9VideoConfiguration.
        :type: float
        """

        if min_keyframe_interval is not None:
            if not isinstance(min_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `min_keyframe_interval`, type has to be `float`")

        self._min_keyframe_interval = min_keyframe_interval

    @property
    def max_keyframe_interval(self):
        # type: () -> float
        """Gets the max_keyframe_interval of this Vp9VideoConfiguration.

        Maximum interval in seconds between key frames

        :return: The max_keyframe_interval of this Vp9VideoConfiguration.
        :rtype: float
        """
        return self._max_keyframe_interval

    @max_keyframe_interval.setter
    def max_keyframe_interval(self, max_keyframe_interval):
        # type: (float) -> None
        """Sets the max_keyframe_interval of this Vp9VideoConfiguration.

        Maximum interval in seconds between key frames

        :param max_keyframe_interval: The max_keyframe_interval of this Vp9VideoConfiguration.
        :type: float
        """

        if max_keyframe_interval is not None:
            if not isinstance(max_keyframe_interval, (float, int)):
                raise TypeError("Invalid type for `max_keyframe_interval`, type has to be `float`")

        self._max_keyframe_interval = max_keyframe_interval

    @property
    def quality(self):
        # type: () -> Vp9Quality
        """Gets the quality of this Vp9VideoConfiguration.


        :return: The quality of this Vp9VideoConfiguration.
        :rtype: Vp9Quality
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        # type: (Vp9Quality) -> None
        """Sets the quality of this Vp9VideoConfiguration.


        :param quality: The quality of this Vp9VideoConfiguration.
        :type: Vp9Quality
        """

        if quality is not None:
            if not isinstance(quality, Vp9Quality):
                raise TypeError("Invalid type for `quality`, type has to be `Vp9Quality`")

        self._quality = quality

    @property
    def lossless(self):
        # type: () -> bool
        """Gets the lossless of this Vp9VideoConfiguration.

        Lossless mode

        :return: The lossless of this Vp9VideoConfiguration.
        :rtype: bool
        """
        return self._lossless

    @lossless.setter
    def lossless(self, lossless):
        # type: (bool) -> None
        """Sets the lossless of this Vp9VideoConfiguration.

        Lossless mode

        :param lossless: The lossless of this Vp9VideoConfiguration.
        :type: bool
        """

        if lossless is not None:
            if not isinstance(lossless, bool):
                raise TypeError("Invalid type for `lossless`, type has to be `bool`")

        self._lossless = lossless

    @property
    def static_thresh(self):
        # type: () -> int
        """Gets the static_thresh of this Vp9VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :return: The static_thresh of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._static_thresh

    @static_thresh.setter
    def static_thresh(self, static_thresh):
        # type: (int) -> None
        """Sets the static_thresh of this Vp9VideoConfiguration.

        A change threshold on blocks below which they will be skipped by the encoder.

        :param static_thresh: The static_thresh of this Vp9VideoConfiguration.
        :type: int
        """

        if static_thresh is not None:
            if static_thresh is not None and static_thresh < 0:
                raise ValueError("Invalid value for `static_thresh`, must be a value greater than or equal to `0`")
            if not isinstance(static_thresh, int):
                raise TypeError("Invalid type for `static_thresh`, type has to be `int`")

        self._static_thresh = static_thresh

    @property
    def aq_mode(self):
        # type: () -> Vp9AqMode
        """Gets the aq_mode of this Vp9VideoConfiguration.


        :return: The aq_mode of this Vp9VideoConfiguration.
        :rtype: Vp9AqMode
        """
        return self._aq_mode

    @aq_mode.setter
    def aq_mode(self, aq_mode):
        # type: (Vp9AqMode) -> None
        """Sets the aq_mode of this Vp9VideoConfiguration.


        :param aq_mode: The aq_mode of this Vp9VideoConfiguration.
        :type: Vp9AqMode
        """

        if aq_mode is not None:
            if not isinstance(aq_mode, Vp9AqMode):
                raise TypeError("Invalid type for `aq_mode`, type has to be `Vp9AqMode`")

        self._aq_mode = aq_mode

    @property
    def arnr_max_frames(self):
        # type: () -> int
        """Gets the arnr_max_frames of this Vp9VideoConfiguration.

        altref noise reduction max frame count.

        :return: The arnr_max_frames of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._arnr_max_frames

    @arnr_max_frames.setter
    def arnr_max_frames(self, arnr_max_frames):
        # type: (int) -> None
        """Sets the arnr_max_frames of this Vp9VideoConfiguration.

        altref noise reduction max frame count.

        :param arnr_max_frames: The arnr_max_frames of this Vp9VideoConfiguration.
        :type: int
        """

        if arnr_max_frames is not None:
            if arnr_max_frames is not None and arnr_max_frames > 15:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value less than or equal to `15`")
            if arnr_max_frames is not None and arnr_max_frames < 0:
                raise ValueError("Invalid value for `arnr_max_frames`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_max_frames, int):
                raise TypeError("Invalid type for `arnr_max_frames`, type has to be `int`")

        self._arnr_max_frames = arnr_max_frames

    @property
    def arnr_strength(self):
        # type: () -> int
        """Gets the arnr_strength of this Vp9VideoConfiguration.

        altref noise reduction filter strength.

        :return: The arnr_strength of this Vp9VideoConfiguration.
        :rtype: int
        """
        return self._arnr_strength

    @arnr_strength.setter
    def arnr_strength(self, arnr_strength):
        # type: (int) -> None
        """Sets the arnr_strength of this Vp9VideoConfiguration.

        altref noise reduction filter strength.

        :param arnr_strength: The arnr_strength of this Vp9VideoConfiguration.
        :type: int
        """

        if arnr_strength is not None:
            if arnr_strength is not None and arnr_strength > 6:
                raise ValueError("Invalid value for `arnr_strength`, must be a value less than or equal to `6`")
            if arnr_strength is not None and arnr_strength < 0:
                raise ValueError("Invalid value for `arnr_strength`, must be a value greater than or equal to `0`")
            if not isinstance(arnr_strength, int):
                raise TypeError("Invalid type for `arnr_strength`, type has to be `int`")

        self._arnr_strength = arnr_strength

    @property
    def arnr_type(self):
        # type: () -> Vp9ArnrType
        """Gets the arnr_type of this Vp9VideoConfiguration.


        :return: The arnr_type of this Vp9VideoConfiguration.
        :rtype: Vp9ArnrType
        """
        return self._arnr_type

    @arnr_type.setter
    def arnr_type(self, arnr_type):
        # type: (Vp9ArnrType) -> None
        """Sets the arnr_type of this Vp9VideoConfiguration.


        :param arnr_type: The arnr_type of this Vp9VideoConfiguration.
        :type: Vp9ArnrType
        """

        if arnr_type is not None:
            if not isinstance(arnr_type, Vp9ArnrType):
                raise TypeError("Invalid type for `arnr_type`, type has to be `Vp9ArnrType`")

        self._arnr_type = arnr_type

    @property
    def auto_level_setup(self):
        # type: () -> AutoLevelSetup
        """Gets the auto_level_setup of this Vp9VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate. Explicitly setting targetLevel, rateOvershootPct, or clientBufferSize properties will automatically disable the calculation.

        :return: The auto_level_setup of this Vp9VideoConfiguration.
        :rtype: AutoLevelSetup
        """
        return self._auto_level_setup

    @auto_level_setup.setter
    def auto_level_setup(self, auto_level_setup):
        # type: (AutoLevelSetup) -> None
        """Sets the auto_level_setup of this Vp9VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate. Explicitly setting targetLevel, rateOvershootPct, or clientBufferSize properties will automatically disable the calculation.

        :param auto_level_setup: The auto_level_setup of this Vp9VideoConfiguration.
        :type: AutoLevelSetup
        """

        if auto_level_setup is not None:
            if not isinstance(auto_level_setup, AutoLevelSetup):
                raise TypeError("Invalid type for `auto_level_setup`, type has to be `AutoLevelSetup`")

        self._auto_level_setup = auto_level_setup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Vp9VideoConfiguration, self), "to_dict"):
            result = super(Vp9VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vp9VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.streams_config_response import StreamsConfigResponse
from bitmovin_api_sdk.models.streams_video_status import StreamsVideoStatus
import pprint
import six


class StreamsVideoResponse(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 asset_url=None,
                 title=None,
                 description=None,
                 created_at=None,
                 status=None,
                 config=None,
                 encoding_tasks=None,
                 poster_url=None):
        # type: (string_types, string_types, string_types, string_types, datetime, StreamsVideoStatus, StreamsConfigResponse, list[StreamsVideoEncodingTask], string_types) -> None

        self._id = None
        self._asset_url = None
        self._title = None
        self._description = None
        self._created_at = None
        self._status = None
        self._config = None
        self._encoding_tasks = list()
        self._poster_url = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if asset_url is not None:
            self.asset_url = asset_url
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if created_at is not None:
            self.created_at = created_at
        if status is not None:
            self.status = status
        if config is not None:
            self.config = config
        if encoding_tasks is not None:
            self.encoding_tasks = encoding_tasks
        if poster_url is not None:
            self.poster_url = poster_url

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'asset_url': 'string_types',
            'title': 'string_types',
            'description': 'string_types',
            'created_at': 'datetime',
            'status': 'StreamsVideoStatus',
            'config': 'StreamsConfigResponse',
            'encoding_tasks': 'list[StreamsVideoEncodingTask]',
            'poster_url': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'asset_url': 'assetUrl',
            'title': 'title',
            'description': 'description',
            'created_at': 'createdAt',
            'status': 'status',
            'config': 'config',
            'encoding_tasks': 'encodingTasks',
            'poster_url': 'posterUrl'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this StreamsVideoResponse.

        The identifier of the stream

        :return: The id of this StreamsVideoResponse.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this StreamsVideoResponse.

        The identifier of the stream

        :param id_: The id of this StreamsVideoResponse.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def asset_url(self):
        # type: () -> string_types
        """Gets the asset_url of this StreamsVideoResponse.

        The asset URL of the stream

        :return: The asset_url of this StreamsVideoResponse.
        :rtype: string_types
        """
        return self._asset_url

    @asset_url.setter
    def asset_url(self, asset_url):
        # type: (string_types) -> None
        """Sets the asset_url of this StreamsVideoResponse.

        The asset URL of the stream

        :param asset_url: The asset_url of this StreamsVideoResponse.
        :type: string_types
        """

        if asset_url is not None:
            if not isinstance(asset_url, string_types):
                raise TypeError("Invalid type for `asset_url`, type has to be `string_types`")

        self._asset_url = asset_url

    @property
    def title(self):
        # type: () -> string_types
        """Gets the title of this StreamsVideoResponse.

        The title of the stream

        :return: The title of this StreamsVideoResponse.
        :rtype: string_types
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (string_types) -> None
        """Sets the title of this StreamsVideoResponse.

        The title of the stream

        :param title: The title of this StreamsVideoResponse.
        :type: string_types
        """

        if title is not None:
            if not isinstance(title, string_types):
                raise TypeError("Invalid type for `title`, type has to be `string_types`")

        self._title = title

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this StreamsVideoResponse.

        The description of the stream

        :return: The description of this StreamsVideoResponse.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this StreamsVideoResponse.

        The description of the stream

        :param description: The description of this StreamsVideoResponse.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this StreamsVideoResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this StreamsVideoResponse.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this StreamsVideoResponse.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this StreamsVideoResponse.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def status(self):
        # type: () -> StreamsVideoStatus
        """Gets the status of this StreamsVideoResponse.

        The status of the stream

        :return: The status of this StreamsVideoResponse.
        :rtype: StreamsVideoStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (StreamsVideoStatus) -> None
        """Sets the status of this StreamsVideoResponse.

        The status of the stream

        :param status: The status of this StreamsVideoResponse.
        :type: StreamsVideoStatus
        """

        if status is not None:
            if not isinstance(status, StreamsVideoStatus):
                raise TypeError("Invalid type for `status`, type has to be `StreamsVideoStatus`")

        self._status = status

    @property
    def config(self):
        # type: () -> StreamsConfigResponse
        """Gets the config of this StreamsVideoResponse.


        :return: The config of this StreamsVideoResponse.
        :rtype: StreamsConfigResponse
        """
        return self._config

    @config.setter
    def config(self, config):
        # type: (StreamsConfigResponse) -> None
        """Sets the config of this StreamsVideoResponse.


        :param config: The config of this StreamsVideoResponse.
        :type: StreamsConfigResponse
        """

        if config is not None:
            if not isinstance(config, StreamsConfigResponse):
                raise TypeError("Invalid type for `config`, type has to be `StreamsConfigResponse`")

        self._config = config

    @property
    def encoding_tasks(self):
        # type: () -> list[StreamsVideoEncodingTask]
        """Gets the encoding_tasks of this StreamsVideoResponse.

        List of encoding status information

        :return: The encoding_tasks of this StreamsVideoResponse.
        :rtype: list[StreamsVideoEncodingTask]
        """
        return self._encoding_tasks

    @encoding_tasks.setter
    def encoding_tasks(self, encoding_tasks):
        # type: (list) -> None
        """Sets the encoding_tasks of this StreamsVideoResponse.

        List of encoding status information

        :param encoding_tasks: The encoding_tasks of this StreamsVideoResponse.
        :type: list[StreamsVideoEncodingTask]
        """

        if encoding_tasks is not None:
            if not isinstance(encoding_tasks, list):
                raise TypeError("Invalid type for `encoding_tasks`, type has to be `list[StreamsVideoEncodingTask]`")

        self._encoding_tasks = encoding_tasks

    @property
    def poster_url(self):
        # type: () -> string_types
        """Gets the poster_url of this StreamsVideoResponse.

        Poster URL

        :return: The poster_url of this StreamsVideoResponse.
        :rtype: string_types
        """
        return self._poster_url

    @poster_url.setter
    def poster_url(self, poster_url):
        # type: (string_types) -> None
        """Sets the poster_url of this StreamsVideoResponse.

        Poster URL

        :param poster_url: The poster_url of this StreamsVideoResponse.
        :type: string_types
        """

        if poster_url is not None:
            if not isinstance(poster_url, string_types):
                raise TypeError("Invalid type for `poster_url`, type has to be `string_types`")

        self._poster_url = poster_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamsVideoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class Period(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 start=None,
                 duration=None):
        # type: (string_types, float, float) -> None
        super(Period, self).__init__(id_=id_)

        self._start = None
        self._duration = None
        self.discriminator = None

        if start is not None:
            self.start = start
        if duration is not None:
            self.duration = duration

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Period, self), 'openapi_types'):
            types = getattr(super(Period, self), 'openapi_types')

        types.update({
            'start': 'float',
            'duration': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Period, self), 'attribute_map'):
            attributes = getattr(super(Period, self), 'attribute_map')

        attributes.update({
            'start': 'start',
            'duration': 'duration'
        })
        return attributes

    @property
    def start(self):
        # type: () -> float
        """Gets the start of this Period.

        Starting time in seconds

        :return: The start of this Period.
        :rtype: float
        """
        return self._start

    @start.setter
    def start(self, start):
        # type: (float) -> None
        """Sets the start of this Period.

        Starting time in seconds

        :param start: The start of this Period.
        :type: float
        """

        if start is not None:
            if not isinstance(start, (float, int)):
                raise TypeError("Invalid type for `start`, type has to be `float`")

        self._start = start

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this Period.

        Duration in seconds.<br/>Please note that the duration of a Period is usually determined by the media contained therein.<br/>Setting the `duration` property to a specific value will override this default behaviour.<br/>Warning: Use at your own risk!

        :return: The duration of this Period.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this Period.

        Duration in seconds.<br/>Please note that the duration of a Period is usually determined by the media contained therein.<br/>Setting the `duration` property to a specific value will override this default behaviour.<br/>Warning: Use at your own risk!

        :param duration: The duration of this Period.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Period, self), "to_dict"):
            result = super(Period, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Period):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital_plus.dolby_digital_plus_api import DolbyDigitalPlusApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital_plus.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dolby_digital_plus.dolby_digital_plus_audio_configuration_list_query_params import DolbyDigitalPlusAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_level_setup import AutoLevelSetup
from bitmovin_api_sdk.models.av1_preset_configuration import Av1PresetConfiguration
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
import pprint
import six


class Av1VideoConfiguration(VideoConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None,
                 preset_configuration=None,
                 auto_level_setup=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode, Av1PresetConfiguration, AutoLevelSetup) -> None
        super(Av1VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, width=width, height=height, bitrate=bitrate, rate=rate, pixel_format=pixel_format, color_config=color_config, sample_aspect_ratio_numerator=sample_aspect_ratio_numerator, sample_aspect_ratio_denominator=sample_aspect_ratio_denominator, display_aspect_ratio=display_aspect_ratio, encoding_mode=encoding_mode)

        self._preset_configuration = None
        self._auto_level_setup = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if auto_level_setup is not None:
            self.auto_level_setup = auto_level_setup

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Av1VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(Av1VideoConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'Av1PresetConfiguration',
            'auto_level_setup': 'AutoLevelSetup'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Av1VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(Av1VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'auto_level_setup': 'autoLevelSetup'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> Av1PresetConfiguration
        """Gets the preset_configuration of this Av1VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :return: The preset_configuration of this Av1VideoConfiguration.
        :rtype: Av1PresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (Av1PresetConfiguration) -> None
        """Sets the preset_configuration of this Av1VideoConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :param preset_configuration: The preset_configuration of this Av1VideoConfiguration.
        :type: Av1PresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, Av1PresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `Av1PresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def auto_level_setup(self):
        # type: () -> AutoLevelSetup
        """Gets the auto_level_setup of this Av1VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate.

        :return: The auto_level_setup of this Av1VideoConfiguration.
        :rtype: AutoLevelSetup
        """
        return self._auto_level_setup

    @auto_level_setup.setter
    def auto_level_setup(self, auto_level_setup):
        # type: (AutoLevelSetup) -> None
        """Sets the auto_level_setup of this Av1VideoConfiguration.

        Enable/disable automatic calculation of level, maxBitrate, and bufsize based on the least level that satisfies maximum property values for picture resolution, frame rate, and bit rate.

        :param auto_level_setup: The auto_level_setup of this Av1VideoConfiguration.
        :type: AutoLevelSetup
        """

        if auto_level_setup is not None:
            if not isinstance(auto_level_setup, AutoLevelSetup):
                raise TypeError("Invalid type for `auto_level_setup`, type has to be `AutoLevelSetup`")

        self._auto_level_setup = auto_level_setup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Av1VideoConfiguration, self), "to_dict"):
            result = super(Av1VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Av1VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.statistics.labels.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.labels.daily.daily_statistics_per_label_list_query_params import DailyStatisticsPerLabelListQueryParams
from bitmovin_api_sdk.encoding.statistics.labels.daily.daily_statistics_per_label_list_by_date_range_query_params import DailyStatisticsPerLabelListByDateRangeQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EncodingTemplate(Enum):
    H264 = "H264"
    AV1 = "AV1"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ResponseStatus(Enum):
    SUCCESS = "SUCCESS"
    ERROR = "ERROR"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
from bitmovin_api_sdk.models.simple_encoding_vod_job_output import SimpleEncodingVodJobOutput
import pprint
import six


class SimpleEncodingVodJobUrlOutput(SimpleEncodingVodJobOutput):
    @poscheck_model
    def __init__(self,
                 artifacts=None,
                 url=None,
                 credentials=None,
                 make_public=None):
        # type: (list[SimpleEncodingVodJobOutputArtifact], string_types, SimpleEncodingVodJobCredentials, bool) -> None
        super(SimpleEncodingVodJobUrlOutput, self).__init__(artifacts=artifacts)

        self._url = None
        self._credentials = None
        self._make_public = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if credentials is not None:
            self.credentials = credentials
        if make_public is not None:
            self.make_public = make_public

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SimpleEncodingVodJobUrlOutput, self), 'openapi_types'):
            types = getattr(super(SimpleEncodingVodJobUrlOutput, self), 'openapi_types')

        types.update({
            'url': 'string_types',
            'credentials': 'SimpleEncodingVodJobCredentials',
            'make_public': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SimpleEncodingVodJobUrlOutput, self), 'attribute_map'):
            attributes = getattr(super(SimpleEncodingVodJobUrlOutput, self), 'attribute_map')

        attributes.update({
            'url': 'url',
            'credentials': 'credentials',
            'make_public': 'makePublic'
        })
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this SimpleEncodingVodJobUrlOutput.

        Define a URL pointing to a folder which will be used to upload the encoded assets.  The output folder structure used looks the following way: <br><br> `http://host/my-folder`     <ul>       <li>         `/video`         <ul>           <li>`/h264/{width}x{height}_{bitrate}/` (multiple subfolders containing different output renditions)</li>         </ul>       </li>       <li>`/audio`         <ul>           <li>`/aac/{language}/` - if language is unique (subfolder containing audio output files)</li>           <li>`/aac/{language}_{index}/` - if language is not unique (subfolder containing audio output files)</li>         </ul>       </li>       <li>`/subtitles` (subfolder containing subtitles files)</li>       <li>`/captions` (subfolder containing subtitles files)</li>       <li>`/sprites` (subfolder containing generated sprites)</li>       <li>`/thumbnails` (subfolder containing generated thumbnails)</li>       <li>`/index.m3u8` (HLS manifest file) </li>       <li>`/stream.mpd` (DASH manifest file) </li>     </ul>    Currently the following protocols/storages systems are supported: S3, GCS, Azure Blob Storage, Akamai NetStorage. Note that most protocols will require `credentials` to access the asset. Check in the descriptions below which properties can or need to be provided within the `credentials` key. See below how to construct the URLs for the individual protocols/storage systems. ___ **Recommendation** To ensure uniqueness of output paths accross multiple encodings, make use of the following placeholders in the output's URL: {uuid} - will be replaced with a random UUID {asset} - will be replaced with the asset file name (only for the input type VIDEO or DEFAULT)  Examples:  * using the `{uuid}` placeholder: The output URL `s3://<my-bucket>/{uuid}/path/` will be transformed to e.g. `s3://<my-bucket>/d59295f3-1548-4bd9-843d-6ac6896dbdb6/path/`.  * using the `{asset}` placeholder: Given an input `s3://my-bucket/path/filename.mp4` of type VIDEO or DEFAULT, the output URL  `s3://<my-bucket>/{asset}/path/` will be transformed to `s3://<my-bucket>/filename/path/`  Notes:   - Placeholders can be combined or used multiple times in the same URL.   - Placeholders are ignored when used in conjunction with `DirectFileUploadInput`s because in this case the asset file name cannot be set. ___  **S3**: * `s3://<my-bucket>/path/`  Authentication can be done via accesskey/secretkey or role-based authentication. Generic S3 is currently NOT supported.  **GCS**: * `gcs://<my-bucket>/path/`  Authentication can be done via accesskey/secretkey or a service account  **Azure Blob Storage (ABS)**: * `https://<account>.blob.core.windows.net/<container>/path/`  It is required to provide the Azure key credentials for authentication.  **Akamai NetStorage**: * `https://<host>-nsu.akamaihd.net/<CP-code>/path/`  It is required to provide username/password credentials for authentication. (required)

        :return: The url of this SimpleEncodingVodJobUrlOutput.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this SimpleEncodingVodJobUrlOutput.

        Define a URL pointing to a folder which will be used to upload the encoded assets.  The output folder structure used looks the following way: <br><br> `http://host/my-folder`     <ul>       <li>         `/video`         <ul>           <li>`/h264/{width}x{height}_{bitrate}/` (multiple subfolders containing different output renditions)</li>         </ul>       </li>       <li>`/audio`         <ul>           <li>`/aac/{language}/` - if language is unique (subfolder containing audio output files)</li>           <li>`/aac/{language}_{index}/` - if language is not unique (subfolder containing audio output files)</li>         </ul>       </li>       <li>`/subtitles` (subfolder containing subtitles files)</li>       <li>`/captions` (subfolder containing subtitles files)</li>       <li>`/sprites` (subfolder containing generated sprites)</li>       <li>`/thumbnails` (subfolder containing generated thumbnails)</li>       <li>`/index.m3u8` (HLS manifest file) </li>       <li>`/stream.mpd` (DASH manifest file) </li>     </ul>    Currently the following protocols/storages systems are supported: S3, GCS, Azure Blob Storage, Akamai NetStorage. Note that most protocols will require `credentials` to access the asset. Check in the descriptions below which properties can or need to be provided within the `credentials` key. See below how to construct the URLs for the individual protocols/storage systems. ___ **Recommendation** To ensure uniqueness of output paths accross multiple encodings, make use of the following placeholders in the output's URL: {uuid} - will be replaced with a random UUID {asset} - will be replaced with the asset file name (only for the input type VIDEO or DEFAULT)  Examples:  * using the `{uuid}` placeholder: The output URL `s3://<my-bucket>/{uuid}/path/` will be transformed to e.g. `s3://<my-bucket>/d59295f3-1548-4bd9-843d-6ac6896dbdb6/path/`.  * using the `{asset}` placeholder: Given an input `s3://my-bucket/path/filename.mp4` of type VIDEO or DEFAULT, the output URL  `s3://<my-bucket>/{asset}/path/` will be transformed to `s3://<my-bucket>/filename/path/`  Notes:   - Placeholders can be combined or used multiple times in the same URL.   - Placeholders are ignored when used in conjunction with `DirectFileUploadInput`s because in this case the asset file name cannot be set. ___  **S3**: * `s3://<my-bucket>/path/`  Authentication can be done via accesskey/secretkey or role-based authentication. Generic S3 is currently NOT supported.  **GCS**: * `gcs://<my-bucket>/path/`  Authentication can be done via accesskey/secretkey or a service account  **Azure Blob Storage (ABS)**: * `https://<account>.blob.core.windows.net/<container>/path/`  It is required to provide the Azure key credentials for authentication.  **Akamai NetStorage**: * `https://<host>-nsu.akamaihd.net/<CP-code>/path/`  It is required to provide username/password credentials for authentication. (required)

        :param url: The url of this SimpleEncodingVodJobUrlOutput.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def credentials(self):
        # type: () -> SimpleEncodingVodJobCredentials
        """Gets the credentials of this SimpleEncodingVodJobUrlOutput.

        Credentials to be used for authentication and accessing the folder 

        :return: The credentials of this SimpleEncodingVodJobUrlOutput.
        :rtype: SimpleEncodingVodJobCredentials
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        # type: (SimpleEncodingVodJobCredentials) -> None
        """Sets the credentials of this SimpleEncodingVodJobUrlOutput.

        Credentials to be used for authentication and accessing the folder 

        :param credentials: The credentials of this SimpleEncodingVodJobUrlOutput.
        :type: SimpleEncodingVodJobCredentials
        """

        if credentials is not None:
            if not isinstance(credentials, SimpleEncodingVodJobCredentials):
                raise TypeError("Invalid type for `credentials`, type has to be `SimpleEncodingVodJobCredentials`")

        self._credentials = credentials

    @property
    def make_public(self):
        # type: () -> bool
        """Gets the make_public of this SimpleEncodingVodJobUrlOutput.

        Indicates if the output should be publically available so that playback immediately works over the internet. Note that not every storage provider supports public output, in this case the flag will be ignored (e.g., Akamai NetStorage).  It might forbidden by some storage configuration to make files public, for example an S3 buckets can be configured to disallow public access. In this case set it to false. 

        :return: The make_public of this SimpleEncodingVodJobUrlOutput.
        :rtype: bool
        """
        return self._make_public

    @make_public.setter
    def make_public(self, make_public):
        # type: (bool) -> None
        """Sets the make_public of this SimpleEncodingVodJobUrlOutput.

        Indicates if the output should be publically available so that playback immediately works over the internet. Note that not every storage provider supports public output, in this case the flag will be ignored (e.g., Akamai NetStorage).  It might forbidden by some storage configuration to make files public, for example an S3 buckets can be configured to disallow public access. In this case set it to false. 

        :param make_public: The make_public of this SimpleEncodingVodJobUrlOutput.
        :type: bool
        """

        if make_public is not None:
            if not isinstance(make_public, bool):
                raise TypeError("Invalid type for `make_public`, type has to be `bool`")

        self._make_public = make_public

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SimpleEncodingVodJobUrlOutput, self), "to_dict"):
            result = super(SimpleEncodingVodJobUrlOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobUrlOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.drm import Drm
from bitmovin_api_sdk.models.speke_drm_provider import SpekeDrmProvider
import pprint
import six


class SpekeDrm(Drm):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 outputs=None,
                 content_id=None,
                 kid=None,
                 iv=None,
                 provider=None,
                 system_ids=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[EncodingOutput], string_types, string_types, string_types, SpekeDrmProvider, list[string_types]) -> None
        super(SpekeDrm, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, outputs=outputs)

        self._content_id = None
        self._kid = None
        self._iv = None
        self._provider = None
        self._system_ids = list()
        self.discriminator = None

        if content_id is not None:
            self.content_id = content_id
        if kid is not None:
            self.kid = kid
        if iv is not None:
            self.iv = iv
        if provider is not None:
            self.provider = provider
        if system_ids is not None:
            self.system_ids = system_ids

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SpekeDrm, self), 'openapi_types'):
            types = getattr(super(SpekeDrm, self), 'openapi_types')

        types.update({
            'content_id': 'string_types',
            'kid': 'string_types',
            'iv': 'string_types',
            'provider': 'SpekeDrmProvider',
            'system_ids': 'list[string_types]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SpekeDrm, self), 'attribute_map'):
            attributes = getattr(super(SpekeDrm, self), 'attribute_map')

        attributes.update({
            'content_id': 'contentId',
            'kid': 'kid',
            'iv': 'iv',
            'provider': 'provider',
            'system_ids': 'systemIds'
        })
        return attributes

    @property
    def content_id(self):
        # type: () -> string_types
        """Gets the content_id of this SpekeDrm.

        Unique Identifier of the content, will be generated if not set

        :return: The content_id of this SpekeDrm.
        :rtype: string_types
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        # type: (string_types) -> None
        """Sets the content_id of this SpekeDrm.

        Unique Identifier of the content, will be generated if not set

        :param content_id: The content_id of this SpekeDrm.
        :type: string_types
        """

        if content_id is not None:
            if not isinstance(content_id, string_types):
                raise TypeError("Invalid type for `content_id`, type has to be `string_types`")

        self._content_id = content_id

    @property
    def kid(self):
        # type: () -> string_types
        """Gets the kid of this SpekeDrm.

        Optional key identifier, will be generated if not set. For SPEKE DRM Configurations with the same contentId and kid the key provider will provide the same keys. 

        :return: The kid of this SpekeDrm.
        :rtype: string_types
        """
        return self._kid

    @kid.setter
    def kid(self, kid):
        # type: (string_types) -> None
        """Sets the kid of this SpekeDrm.

        Optional key identifier, will be generated if not set. For SPEKE DRM Configurations with the same contentId and kid the key provider will provide the same keys. 

        :param kid: The kid of this SpekeDrm.
        :type: string_types
        """

        if kid is not None:
            if not isinstance(kid, string_types):
                raise TypeError("Invalid type for `kid`, type has to be `string_types`")

        self._kid = kid

    @property
    def iv(self):
        # type: () -> string_types
        """Gets the iv of this SpekeDrm.

        16 byte initialization vector represented by a 32-character text string. It is mandatory if systemIds contains AES128 or FairPlay. 

        :return: The iv of this SpekeDrm.
        :rtype: string_types
        """
        return self._iv

    @iv.setter
    def iv(self, iv):
        # type: (string_types) -> None
        """Sets the iv of this SpekeDrm.

        16 byte initialization vector represented by a 32-character text string. It is mandatory if systemIds contains AES128 or FairPlay. 

        :param iv: The iv of this SpekeDrm.
        :type: string_types
        """

        if iv is not None:
            if not isinstance(iv, string_types):
                raise TypeError("Invalid type for `iv`, type has to be `string_types`")

        self._iv = iv

    @property
    def provider(self):
        # type: () -> SpekeDrmProvider
        """Gets the provider of this SpekeDrm.

        Key provider configuration for SPEKE (required)

        :return: The provider of this SpekeDrm.
        :rtype: SpekeDrmProvider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        # type: (SpekeDrmProvider) -> None
        """Sets the provider of this SpekeDrm.

        Key provider configuration for SPEKE (required)

        :param provider: The provider of this SpekeDrm.
        :type: SpekeDrmProvider
        """

        if provider is not None:
            if not isinstance(provider, SpekeDrmProvider):
                raise TypeError("Invalid type for `provider`, type has to be `SpekeDrmProvider`")

        self._provider = provider

    @property
    def system_ids(self):
        # type: () -> list[string_types]
        """Gets the system_ids of this SpekeDrm.

        DRM system identifier of the content protection scheme. At minimum one is expected. Not all systemIds are currently supported, support depends on the muxing type.  Relates to SPEKE implementation. See https://dashif.org/identifiers/content_protection/ (required)

        :return: The system_ids of this SpekeDrm.
        :rtype: list[string_types]
        """
        return self._system_ids

    @system_ids.setter
    def system_ids(self, system_ids):
        # type: (list) -> None
        """Sets the system_ids of this SpekeDrm.

        DRM system identifier of the content protection scheme. At minimum one is expected. Not all systemIds are currently supported, support depends on the muxing type.  Relates to SPEKE implementation. See https://dashif.org/identifiers/content_protection/ (required)

        :param system_ids: The system_ids of this SpekeDrm.
        :type: list[string_types]
        """

        if system_ids is not None:
            if not isinstance(system_ids, list):
                raise TypeError("Invalid type for `system_ids`, type has to be `list[string_types]`")

        self._system_ids = system_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SpekeDrm, self), "to_dict"):
            result = super(SpekeDrm, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpekeDrm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.codec_configuration import CodecConfiguration
from bitmovin_api_sdk.models.color_config import ColorConfig
from bitmovin_api_sdk.models.display_aspect_ratio import DisplayAspectRatio
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.pixel_format import PixelFormat
import pprint
import six


class VideoConfiguration(CodecConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 width=None,
                 height=None,
                 bitrate=None,
                 rate=None,
                 pixel_format=None,
                 color_config=None,
                 sample_aspect_ratio_numerator=None,
                 sample_aspect_ratio_denominator=None,
                 display_aspect_ratio=None,
                 encoding_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, int, float, PixelFormat, ColorConfig, int, int, DisplayAspectRatio, EncodingMode) -> None
        super(VideoConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._width = None
        self._height = None
        self._bitrate = None
        self._rate = None
        self._pixel_format = None
        self._color_config = None
        self._sample_aspect_ratio_numerator = None
        self._sample_aspect_ratio_denominator = None
        self._display_aspect_ratio = None
        self._encoding_mode = None
        self.discriminator = None

        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if bitrate is not None:
            self.bitrate = bitrate
        if rate is not None:
            self.rate = rate
        if pixel_format is not None:
            self.pixel_format = pixel_format
        if color_config is not None:
            self.color_config = color_config
        if sample_aspect_ratio_numerator is not None:
            self.sample_aspect_ratio_numerator = sample_aspect_ratio_numerator
        if sample_aspect_ratio_denominator is not None:
            self.sample_aspect_ratio_denominator = sample_aspect_ratio_denominator
        if display_aspect_ratio is not None:
            self.display_aspect_ratio = display_aspect_ratio
        if encoding_mode is not None:
            self.encoding_mode = encoding_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(VideoConfiguration, self), 'openapi_types'):
            types = getattr(super(VideoConfiguration, self), 'openapi_types')

        types.update({
            'width': 'int',
            'height': 'int',
            'bitrate': 'int',
            'rate': 'float',
            'pixel_format': 'PixelFormat',
            'color_config': 'ColorConfig',
            'sample_aspect_ratio_numerator': 'int',
            'sample_aspect_ratio_denominator': 'int',
            'display_aspect_ratio': 'DisplayAspectRatio',
            'encoding_mode': 'EncodingMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(VideoConfiguration, self), 'attribute_map'):
            attributes = getattr(super(VideoConfiguration, self), 'attribute_map')

        attributes.update({
            'width': 'width',
            'height': 'height',
            'bitrate': 'bitrate',
            'rate': 'rate',
            'pixel_format': 'pixelFormat',
            'color_config': 'colorConfig',
            'sample_aspect_ratio_numerator': 'sampleAspectRatioNumerator',
            'sample_aspect_ratio_denominator': 'sampleAspectRatioDenominator',
            'display_aspect_ratio': 'displayAspectRatio',
            'encoding_mode': 'encodingMode'
        })
        return attributes

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this VideoConfiguration.

        Width of the encoded video in pixels

        :return: The width of this VideoConfiguration.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this VideoConfiguration.

        Width of the encoded video in pixels

        :param width: The width of this VideoConfiguration.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this VideoConfiguration.

        Height of the encoded video in pixels

        :return: The height of this VideoConfiguration.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this VideoConfiguration.

        Height of the encoded video in pixels

        :param height: The height of this VideoConfiguration.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this VideoConfiguration.

        Target bitrate for the encoded video in bps. Either bitrate or crf is required.

        :return: The bitrate of this VideoConfiguration.
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this VideoConfiguration.

        Target bitrate for the encoded video in bps. Either bitrate or crf is required.

        :param bitrate: The bitrate of this VideoConfiguration.
        :type: int
        """

        if bitrate is not None:
            if not isinstance(bitrate, int):
                raise TypeError("Invalid type for `bitrate`, type has to be `int`")

        self._bitrate = bitrate

    @property
    def rate(self):
        # type: () -> float
        """Gets the rate of this VideoConfiguration.

        Target frame rate of the encoded video. Must be set for live encodings

        :return: The rate of this VideoConfiguration.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (float) -> None
        """Sets the rate of this VideoConfiguration.

        Target frame rate of the encoded video. Must be set for live encodings

        :param rate: The rate of this VideoConfiguration.
        :type: float
        """

        if rate is not None:
            if not isinstance(rate, (float, int)):
                raise TypeError("Invalid type for `rate`, type has to be `float`")

        self._rate = rate

    @property
    def pixel_format(self):
        # type: () -> PixelFormat
        """Gets the pixel_format of this VideoConfiguration.

        Describes the color encoding, bit depth, and chroma subsampling of each pixel in the output image.

        :return: The pixel_format of this VideoConfiguration.
        :rtype: PixelFormat
        """
        return self._pixel_format

    @pixel_format.setter
    def pixel_format(self, pixel_format):
        # type: (PixelFormat) -> None
        """Sets the pixel_format of this VideoConfiguration.

        Describes the color encoding, bit depth, and chroma subsampling of each pixel in the output image.

        :param pixel_format: The pixel_format of this VideoConfiguration.
        :type: PixelFormat
        """

        if pixel_format is not None:
            if not isinstance(pixel_format, PixelFormat):
                raise TypeError("Invalid type for `pixel_format`, type has to be `PixelFormat`")

        self._pixel_format = pixel_format

    @property
    def color_config(self):
        # type: () -> ColorConfig
        """Gets the color_config of this VideoConfiguration.


        :return: The color_config of this VideoConfiguration.
        :rtype: ColorConfig
        """
        return self._color_config

    @color_config.setter
    def color_config(self, color_config):
        # type: (ColorConfig) -> None
        """Sets the color_config of this VideoConfiguration.


        :param color_config: The color_config of this VideoConfiguration.
        :type: ColorConfig
        """

        if color_config is not None:
            if not isinstance(color_config, ColorConfig):
                raise TypeError("Invalid type for `color_config`, type has to be `ColorConfig`")

        self._color_config = color_config

    @property
    def sample_aspect_ratio_numerator(self):
        # type: () -> int
        """Gets the sample_aspect_ratio_numerator of this VideoConfiguration.

        The numerator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioDenominator is set. If set then displayAspectRatio is not allowed.

        :return: The sample_aspect_ratio_numerator of this VideoConfiguration.
        :rtype: int
        """
        return self._sample_aspect_ratio_numerator

    @sample_aspect_ratio_numerator.setter
    def sample_aspect_ratio_numerator(self, sample_aspect_ratio_numerator):
        # type: (int) -> None
        """Sets the sample_aspect_ratio_numerator of this VideoConfiguration.

        The numerator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioDenominator is set. If set then displayAspectRatio is not allowed.

        :param sample_aspect_ratio_numerator: The sample_aspect_ratio_numerator of this VideoConfiguration.
        :type: int
        """

        if sample_aspect_ratio_numerator is not None:
            if not isinstance(sample_aspect_ratio_numerator, int):
                raise TypeError("Invalid type for `sample_aspect_ratio_numerator`, type has to be `int`")

        self._sample_aspect_ratio_numerator = sample_aspect_ratio_numerator

    @property
    def sample_aspect_ratio_denominator(self):
        # type: () -> int
        """Gets the sample_aspect_ratio_denominator of this VideoConfiguration.

        The denominator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioNumerator is set. If set then displayAspectRatio is not allowed.

        :return: The sample_aspect_ratio_denominator of this VideoConfiguration.
        :rtype: int
        """
        return self._sample_aspect_ratio_denominator

    @sample_aspect_ratio_denominator.setter
    def sample_aspect_ratio_denominator(self, sample_aspect_ratio_denominator):
        # type: (int) -> None
        """Sets the sample_aspect_ratio_denominator of this VideoConfiguration.

        The denominator of the sample aspect ratio (also known as pixel aspect ratio). Must be set if sampleAspectRatioNumerator is set. If set then displayAspectRatio is not allowed.

        :param sample_aspect_ratio_denominator: The sample_aspect_ratio_denominator of this VideoConfiguration.
        :type: int
        """

        if sample_aspect_ratio_denominator is not None:
            if not isinstance(sample_aspect_ratio_denominator, int):
                raise TypeError("Invalid type for `sample_aspect_ratio_denominator`, type has to be `int`")

        self._sample_aspect_ratio_denominator = sample_aspect_ratio_denominator

    @property
    def display_aspect_ratio(self):
        # type: () -> DisplayAspectRatio
        """Gets the display_aspect_ratio of this VideoConfiguration.

        Specifies a display aspect ratio (DAR) to be enforced. The sample aspect ratio (SAR) will be adjusted accordingly. If set then sampleAspectRatioNumerator and sampleAspectRatioDenominator are not allowed.

        :return: The display_aspect_ratio of this VideoConfiguration.
        :rtype: DisplayAspectRatio
        """
        return self._display_aspect_ratio

    @display_aspect_ratio.setter
    def display_aspect_ratio(self, display_aspect_ratio):
        # type: (DisplayAspectRatio) -> None
        """Sets the display_aspect_ratio of this VideoConfiguration.

        Specifies a display aspect ratio (DAR) to be enforced. The sample aspect ratio (SAR) will be adjusted accordingly. If set then sampleAspectRatioNumerator and sampleAspectRatioDenominator are not allowed.

        :param display_aspect_ratio: The display_aspect_ratio of this VideoConfiguration.
        :type: DisplayAspectRatio
        """

        if display_aspect_ratio is not None:
            if not isinstance(display_aspect_ratio, DisplayAspectRatio):
                raise TypeError("Invalid type for `display_aspect_ratio`, type has to be `DisplayAspectRatio`")

        self._display_aspect_ratio = display_aspect_ratio

    @property
    def encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the encoding_mode of this VideoConfiguration.

        The mode of the encoding

        :return: The encoding_mode of this VideoConfiguration.
        :rtype: EncodingMode
        """
        return self._encoding_mode

    @encoding_mode.setter
    def encoding_mode(self, encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the encoding_mode of this VideoConfiguration.

        The mode of the encoding

        :param encoding_mode: The encoding_mode of this VideoConfiguration.
        :type: EncodingMode
        """

        if encoding_mode is not None:
            if not isinstance(encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `encoding_mode`, type has to be `EncodingMode`")

        self._encoding_mode = encoding_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(VideoConfiguration, self), "to_dict"):
            result = super(VideoConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
